@@ -1,10 +1,10 @@
 /* copyout.c - create a cpio archive
    Copyright (C) 1990, 1991, 1992, 2001, 2003, 2004,
-   2006 Free Software Foundation, Inc.
+   2006, 2007, 2009 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
+   the Free Software Foundation; either version 3, or (at your option)
    any later version.
 
    This program is distributed in the hope that it will be useful,
@@ -33,10 +33,10 @@
 /* Read FILE_SIZE bytes of FILE_NAME from IN_FILE_DES and
    compute and return a checksum for them.  */
 
-static unsigned int
+static unsigned long
 read_for_checksum (int in_file_des, int file_size, char *file_name)
 {
-  unsigned int crc;
+  unsigned long crc;
   char buf[BUFSIZ];
   int bytes_left;
   int bytes_read;
@@ -595,7 +595,6 @@ assign_string (char **pvar, char *value)
 void
 process_copy_out ()
 {
-  int res;			/* Result of functions.  */
   dynamic_string input_name;	/* Name of file read from stdin.  */
   struct stat file_stat;	/* Stat record for file.  */
   struct cpio_file_stat file_hdr; /* Output header information.  */
@@ -889,8 +888,10 @@ process_copy_out ()
     fputc ('\n', stderr);
   if (!quiet_flag)
     {
-      res = (output_bytes + io_block_size - 1) / io_block_size;
-      fprintf (stderr, ngettext ("%d block\n", "%d blocks\n", res), res);
+      size_t blocks = (output_bytes + io_block_size - 1) / io_block_size;
+      fprintf (stderr,
+	       ngettext ("%lu block\n", "%lu blocks\n",
+			 (unsigned long) blocks), (unsigned long) blocks);
     }
 }
 
